@@ -2,10 +2,12 @@
 
 import sys
 
+
 def main():
     from .ui import main as realmain
 
     sys.exit(realmain())
 
-if __name__ == '__main__':
+
+if __name__ == "__main__":
     main()
