@@ -57,11 +57,7 @@ def dump_thread(thread, output_dir):
     )
     template = env.get_template("thread.html")
 
-    # Get thread name and determine if group
-    thread_name = thread.recipient.name[0].strip()
-    is_group = False
-    if thread.recipient.recipientId._id.startswith("__textsecure_group__"):
-        is_group = True
+    is_group = thread.recipient.isgroup
 
     # Create the message color CSS (depends on individuals)
     group_color_css = ""
@@ -72,13 +68,15 @@ def dump_thread(thread, output_dir):
         colors_used = []
         group_colors = set(ar.color for ar in sender_idx)
         for ar, idx in sender_idx.items():
-            if ar.recipientId._id.startswith("__textsecure_group__"):
+            if ar.isgroup:
                 continue
+
             # ensure colors are unique, even if they're not in Signal
             ar_color = ar.color
             if ar_color in colors_used:
                 color = next(
-                    (c for c in COLORMAP if not c in group_colors), None,
+                    (c for c in COLORMAP if not c in group_colors),
+                    None,
                 )
                 ar_color = ar.color if color is None else color
             group_color_css += msg_css % (idx, COLORMAP[ar_color])
@@ -95,6 +93,7 @@ def dump_thread(thread, output_dir):
     prev_date = None
     simple_messages = []
     for msg in messages:
+
         if is_joined_type(msg._type):
             continue
 
@@ -113,7 +112,7 @@ def dump_thread(thread, output_dir):
         is_call = False
         if is_incoming_call(msg._type):
             is_call = True
-            msg.body = f"{thread_name} called you"
+            msg.body = f"{thread.name} called you"
         elif is_outgoing_call(msg._type):
             is_call = True
             msg.body = "You called"
@@ -125,7 +124,7 @@ def dump_thread(thread, output_dir):
         quote = {}
         if isinstance(msg, MMSMessageRecord) and msg.quote:
             quote_author_id = msg.quote.author.recipientId._id
-            quote_author_name = msg.quote.author.name[0]
+            quote_author_name = msg.quote.author.name
             if quote_author_id == quote_author_name:
                 name = "You"
             else:
@@ -155,7 +154,7 @@ def dump_thread(thread, output_dir):
             "date": date_sent,
             "attachments": [],
             "id": msg._id,
-            "name": aR.name[0],
+            "name": aR.name,
             "sender_idx": sender_idx[aR] if is_group else "0",
             "quote": quote,
         }
@@ -174,13 +173,15 @@ def dump_thread(thread, output_dir):
         return
 
     html = template.render(
-        thread_name=thread_name,
+        thread_name=thread.name,
         messages=simple_messages,
         group_color_css=group_color_css,
     )
 
+    os.makedirs(output_dir, exist_ok=True)
+
     filename = os.path.join(
-        output_dir, thread_name.replace(" ", "_") + ".html"
+        output_dir, thread.name.replace(" ", "_") + ".html"
     )
-    with open(filename, "w") as fp:
+    with open(filename, "w", encoding="utf-8") as fp:
         fp.write(html)
