@@ -47,6 +47,7 @@ class Recipient:
     recipientId: RecipientId
     name: str
     color: str
+    isgroup: bool
 
     def __hash__(self):
         return hash(self.recipientId)
@@ -82,6 +83,10 @@ class SMSMessageRecord(MessageRecord):
 @dataclass
 class Thread:
     _id: int
-    recipient: Recipient  # need to deal with groups later
+    recipient: Recipient
     mms: List[MMSMessageRecord] = field(default_factory=lambda: [])
     sms: List[SMSMessageRecord] = field(default_factory=lambda: [])
+
+    @property
+    def name(self):
+        return self.recipient.name.strip()
